@@ -1,12 +1,12 @@
 import { Store } from 'pullstate';
 export const initialState = {
     fileDetails: {},
-    containerDetails: {}
+    collectionDetails: {}
 };
 export const UIStore = new Store(initialState);
 export const resetRucioCaches = () => {
     UIStore.update(s => {
         s.fileDetails = {};
-        s.containerDetails = {};
+        s.collectionDetails = {};
     });
 };
