@@ -1,6 +1,5 @@
 import { JupyterFrontEnd, JupyterFrontEndPlugin, ILabShell } from '@jupyterlab/application';
 import { INotebookTracker } from '@jupyterlab/notebook';
-import { ISettingRegistry } from '@jupyterlab/settingregistry';
 import { EXTENSION_ID } from './const';
 import { SidebarPanel } from './SidebarPanel';
 import { actions } from './utils/Actions';
@@ -11,24 +10,24 @@ import { actions } from './utils/Actions';
 const extension: JupyterFrontEndPlugin<void> = {
   id: EXTENSION_ID,
   autoStart: true,
-  requires: [ILabShell, ISettingRegistry, INotebookTracker],
-  activate: async (
-    app: JupyterFrontEnd,
-    labShell: ILabShell,
-    settingRegistry: ISettingRegistry,
-    notebookTracker: INotebookTracker
-  ) => {
-    const instanceConfig = await actions.fetchInstancesConfig();
-    const options = {
-      app,
-      settingRegistry,
-      labShell,
-      notebookTracker,
-      widgetId: `${EXTENSION_ID}:panel`,
-      instanceConfig
-    };
+  requires: [ILabShell, INotebookTracker],
+  activate: async (app: JupyterFrontEnd, labShell: ILabShell, notebookTracker: INotebookTracker) => {
+    let options;
+
+    try {
+      const instanceConfig = await actions.fetchInstancesConfig();
+      options = {
+        app,
+        labShell,
+        notebookTracker,
+        instanceConfig
+      };
+    } catch (e) {
+      console.log(e);
+    }
 
     const sidebarPanel = new SidebarPanel(options);
+    sidebarPanel.id = EXTENSION_ID + ':panel';
     labShell.add(sidebarPanel, 'left', { rank: 900 });
     labShell.activateById(sidebarPanel.id);
   }
