@@ -42,9 +42,23 @@ export interface FileDIDDetails {
 export interface NotebookDIDAttachment {
   did: string;
   variableName: string;
-  type: 'container' | 'file';
+  type: 'collection' | 'file';
+}
+
+export interface DirectoryItem {
+  type: 'file' | 'dir';
+  name: string;
+  path: string;
 }
 
 export type FileStatus = 'OK' | 'REPLICATING' | 'NOT_AVAILABLE' | 'STUCK';
-export type ContainerStatus = 'NOT_AVAILABLE' | 'AVAILABLE' | 'PARTIALLY_AVAILABLE' | 'REPLICATING' | 'STUCK';
+export type CollectionStatus = 'NOT_AVAILABLE' | 'AVAILABLE' | 'PARTIALLY_AVAILABLE' | 'REPLICATING' | 'STUCK';
 export type ResolveStatus = 'NOT_RESOLVED' | 'RESOLVING' | 'PENDING_INJECTION' | 'READY' | 'FAILED';
+
+export type DIDSearchType = 'collection' | 'dataset' | 'container' | 'file' | 'all';
+
+export interface DIDSearchResult {
+  did: string;
+  type: 'dataset' | 'container' | 'file';
+  size?: number;
+}
