@@ -8,11 +8,13 @@ import { NotebookDIDAttachment, FileDIDDetails, ResolveStatus } from '../types';
 import { COMM_NAME_KERNEL, COMM_NAME_FRONTEND, METADATA_KEY } from '../const';
 import { actions } from '../utils/Actions';
 import { InjectNotebookToolbar } from '../InjectNotebookToolbar';
+import { computeCollectionState } from './Helpers';
 
 interface NotebookVariableInjection {
   variableName: string;
   path: string | string[];
   did: string;
+  didAvailable?: boolean;
 }
 
 type StatusMap = { [notebookId: string]: { [did: string]: ResolveStatus } };
@@ -45,8 +47,6 @@ export class NotebookListener {
     const { notebookTracker } = this.options;
 
     const instanceConfigurationChange = () => {
-      console.log('[Listener] Instance config changed!');
-
       StatusStore.update(s => {
         s.status = {};
       });
@@ -70,6 +70,9 @@ export class NotebookListener {
     panel.sessionContext.statusChanged.connect((sender, status) => {
       if (status === 'restarting') {
         this.onKernelRestarted(panel, sender.session.kernel);
+        panel.sessionContext.ready.then(() => {
+          this.onKernelAttached(panel, sender.session.kernel);
+        });
       }
     });
     panel.sessionContext.kernelChanged.connect((sender, changed) => {
@@ -138,7 +141,6 @@ export class NotebookListener {
     msg: KernelMessage.ICommMsgMsg | KernelMessage.ICommOpenMsg
   ) {
     const data = msg.content.data;
-    console.log('Incoming message', data);
     if (data.action === 'request-inject') {
       const { activeInstance } = UIStore.getRawState();
       const notebookId = this.getNotebookIdFromKernelConnectionId(kernelConnection.id);
@@ -151,7 +153,6 @@ export class NotebookListener {
       }
 
       this.resolveAttachments(activeNotebookAttachments, kernelConnection.id).then(injections => {
-        console.log('Replying request-inject', injections);
         return comm
           .send({ action: 'inject', dids: injections as any })
           .done.then(() => {
@@ -179,6 +180,16 @@ export class NotebookListener {
     this.injectAttachments(kernel, attachments);
   }
 
+  reinjectSpecificDID(notebookPanel: NotebookPanel, did: string): void {
+    const attachments = this.getAttachmentsFromMetadata(notebookPanel);
+    const didAttachment = attachments.find(a => a.did === did);
+
+    if (didAttachment) {
+      const kernel = notebookPanel.sessionContext?.session?.kernel;
+      this.injectAttachments(kernel, [didAttachment]);
+    }
+  }
+
   private getAttachmentsFromMetadata(notebook: NotebookPanel): NotebookDIDAttachment[] {
     const rucioDidAttachments = notebook.model.metadata.get(METADATA_KEY);
     const attachedDIDs = rucioDidAttachments as ReadonlyArray<any>;
@@ -197,14 +208,16 @@ export class NotebookListener {
     const notebookId = this.getNotebookIdFromKernelConnectionId(kernelConnectionId);
     StatusStore.update(s => {
       const notebookStatus = s.status[notebookId];
-      const injectedDIDs = Object.keys(notebookStatus);
-      const nonExistentDIDs = injectedDIDs.filter(did => !attachments.find(a => a.did === did));
-      nonExistentDIDs.forEach(nd => delete s.status[notebookId][nd]);
+      if (notebookStatus) {
+        const injectedDIDs = Object.keys(notebookStatus);
+        const nonExistentDIDs = injectedDIDs.filter(did => !attachments.find(a => a.did === did));
+        nonExistentDIDs.forEach(nd => delete s.status[notebookId][nd]);
+      }
     });
   }
 
   private injectAttachments(kernel: Kernel.IKernelConnection, attachments: NotebookDIDAttachment[]) {
-    if (!this.isExtensionProperlySetup()) {
+    if (!this.isExtensionProperlySetup() || !attachments) {
       return;
     }
 
@@ -226,8 +239,6 @@ export class NotebookListener {
       return;
     }
 
-    console.log('Injecting variables', injections);
-
     const comm = kernel.createComm(COMM_NAME_KERNEL);
     return comm
       .open()
@@ -250,13 +261,16 @@ export class NotebookListener {
     const { variableName, type, did } = attachment;
     this.setResolveStatus(kernelConnectionId, did, 'RESOLVING');
     try {
-      if (type === 'container') {
-        const didDetails = await this.resolveContainerDIDDetails(did);
-        const path = this.getContainerDIDPaths(didDetails);
+      if (type === 'collection') {
+        const didDetails = await this.resolveCollectionDIDDetails(did);
+        const path = this.getCollectionDIDPaths(didDetails);
 
         this.setResolveStatus(kernelConnectionId, did, 'PENDING_INJECTION');
 
-        return { variableName, path, did };
+        const collectionStatus = computeCollectionState(didDetails);
+        const didAvailable = collectionStatus === 'AVAILABLE';
+
+        return { variableName, path, did, didAvailable };
       } else {
         const didDetails = await this.resolveFileDIDDetails(did);
         const path = this.getFileDIDPaths(didDetails);
@@ -282,7 +296,7 @@ export class NotebookListener {
     });
   }
 
-  private getContainerDIDPaths(didDetails: FileDIDDetails[]): string[] {
+  private getCollectionDIDPaths(didDetails: FileDIDDetails[]): string[] {
     return didDetails.map(d => d.path).filter(p => !!p);
   }
 
@@ -295,9 +309,9 @@ export class NotebookListener {
     return actions.getFileDIDDetails(activeInstance.name, did);
   }
 
-  private async resolveContainerDIDDetails(did: string): Promise<FileDIDDetails[]> {
+  private async resolveCollectionDIDDetails(did: string): Promise<FileDIDDetails[]> {
     const { activeInstance } = UIStore.getRawState();
-    return actions.getContainerDIDDetails(activeInstance.name, did);
+    return actions.getCollectionDIDDetails(activeInstance.name, did);
   }
 
   private getNotebookIdFromKernelConnectionId(kernelConnectionId: string) {
